==> amulet_utils-1.0.0.tar.gz: amulet_utils-1.0.0/src/amulet/utils/logging/logging.hpp <==
#pragma once

#include <iostream>
#include <string>

#include <amulet/utils/dll.hpp>

namespace Amulet {

// Forward declare Signal
template <typename... Args>
class Signal;

// Register the default log handler.
// This is registered by default with a log level of 20.
// Thread safe.
AMULET_UTILS_EXPORT void register_default_log_handler();

// Unregister the default log handler.
// Thread safe.
AMULET_UTILS_EXPORT void unregister_default_log_handler();

// Get the maximum message level that will be logged.
// Registered handlers may be more strict.
// Thread safe.
AMULET_UTILS_EXPORT int& get_min_log_level();

// Set the maximum message level that will be logged.
// Registered handlers may be more strict.
// Thread safe.
AMULET_UTILS_EXPORT void set_min_log_level(int);

// Get the logger signal.
// This is emitted with the message and its level every time a message is logged.
AMULET_UTILS_EXPORT Signal<int, std::string>& get_logger();

// Log a message with a custom level.
// If the level is less than the configured log level this will do nothing.
// Thread safe.
AMULET_UTILS_EXPORT void log(int level, const std::string& msg);

// Log a message with debug level (10).
// Thread safe.
AMULET_UTILS_EXPORT void debug(const std::string& msg);

// Log a message with info level (20).
// Thread safe.
AMULET_UTILS_EXPORT void info(const std::string& msg);

// Log a message with warning level (30).
// Thread safe.
AMULET_UTILS_EXPORT void warning(const std::string& msg);

// Log a message with error level (40).
// Thread safe.
AMULET_UTILS_EXPORT void error(const std::string& msg);

// Log a message with info level (50).
// Thread safe.
AMULET_UTILS_EXPORT void critical(const std::string& msg);

}

// Some places can't use the normal logging system.
// This macro can be used to log directly.
#define Log(level, msg)                     \
    {                                       \
        if (get_min_log_level() <= level) { \
            std::cout << msg << std::endl;  \
        }                                   \
    }

#include <amulet/utils/signal/signal.hpp>

==> amulet_utils-1.1.0a6.tar.gz: amulet_utils-1.1.0a6/src/amulet/utils/logging/logging.hpp <==
#pragma once

#include <iostream>
#include <string>

#include <amulet/utils/dll.hpp>

namespace Amulet {

// Forward declare Signal
template <typename... Args>
class Signal;

// Register the default log handler.
// This is registered by default with a log level of 20.
// Thread safe.
AMULET_UTILS_EXPORT void register_default_log_handler();

// Unregister the default log handler.
// Thread safe.
AMULET_UTILS_EXPORT void unregister_default_log_handler();

// Get the maximum message level that will be logged.
// Registered handlers may be more strict.
// Thread safe.
AMULET_UTILS_EXPORT int& get_min_log_level();

// Set the maximum message level that will be logged.
// Registered handlers may be more strict.
// Thread safe.
AMULET_UTILS_EXPORT void set_min_log_level(int);

// Get the logger signal.
// This is emitted with the message and its level every time a message is logged.
AMULET_UTILS_EXPORT Signal<int, std::string>& get_logger();

// Log a message with a custom level.
// If the level is less than the configured log level this will do nothing.
// Thread safe.
AMULET_UTILS_EXPORT void log(int level, const std::string& msg);

// Log a message with debug level (10).
// Thread safe.
AMULET_UTILS_EXPORT void debug(const std::string& msg);

// Log a message with info level (20).
// Thread safe.
AMULET_UTILS_EXPORT void info(const std::string& msg);

// Log a message with warning level (30).
// Thread safe.
AMULET_UTILS_EXPORT void warning(const std::string& msg);

// Log a message with error level (40).
// Thread safe.
AMULET_UTILS_EXPORT void error(const std::string& msg);

// Log a message with info level (50).
// Thread safe.
AMULET_UTILS_EXPORT void critical(const std::string& msg);

}

// Some places can't use the normal logging system.
// This macro can be used to log directly.
#define AmuletLog(level, msg)                     \
    {                                       \
        if (get_min_log_level() <= level) { \
            std::cout << msg << std::endl;  \
        }                                   \
    }

#include <amulet/utils/signal/signal.hpp>
